==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/cloudwatch/kotlin/inputs/MetricStreamIncludeFilterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudwatch.kotlin.inputs

import com.pulumi.aws.cloudwatch.inputs.MetricStreamIncludeFilterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property metricNames An array that defines the metrics you want to include for this metric namespace
 * @property namespace Name of the metric namespace in the filter.
 */
public data class MetricStreamIncludeFilterArgs(
    public val metricNames: Output<List<String>>? = null,
    public val namespace: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.cloudwatch.inputs.MetricStreamIncludeFilterArgs> {
    override fun toJava(): com.pulumi.aws.cloudwatch.inputs.MetricStreamIncludeFilterArgs =
        com.pulumi.aws.cloudwatch.inputs.MetricStreamIncludeFilterArgs.builder()
            .metricNames(metricNames?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .namespace(namespace.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MetricStreamIncludeFilterArgs].
 */
@PulumiTagMarker
public class MetricStreamIncludeFilterArgsBuilder internal constructor() {
    private var metricNames: Output<List<String>>? = null

    private var namespace: Output<String>? = null

    /**
     * @param value An array that defines the metrics you want to include for this metric namespace
     */
    @JvmName("hdpxqkhaaoakeeqm")
    public suspend fun metricNames(`value`: Output<List<String>>) {
        this.metricNames = value
    }

    @JvmName("hekbuwlnfmlsaenn")
    public suspend fun metricNames(vararg values: Output<String>) {
        this.metricNames = Output.all(values.asList())
    }

    /**
     * @param values An array that defines the metrics you want to include for this metric namespace
     */
    @JvmName("qkbegeyseqeugpfj")
    public suspend fun metricNames(values: List<Output<String>>) {
        this.metricNames = Output.all(values)
    }

    /**
     * @param value Name of the metric namespace in the filter.
     */
    @JvmName("iehecwepkbjsvhsn")
    public suspend fun namespace(`value`: Output<String>) {
        this.namespace = value
    }

    /**
     * @param value An array that defines the metrics you want to include for this metric namespace
     */
    @JvmName("xdkvbslfjlyaepyr")
    public suspend fun metricNames(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.metricNames = mapped
    }

    /**
     * @param values An array that defines the metrics you want to include for this metric namespace
     */
    @JvmName("pnssyyofecqrbieo")
    public suspend fun metricNames(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.metricNames = mapped
    }

    /**
     * @param value Name of the metric namespace in the filter.
     */
    @JvmName("resokwhhactcogeq")
    public suspend fun namespace(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.namespace = mapped
    }

    internal fun build(): MetricStreamIncludeFilterArgs = MetricStreamIncludeFilterArgs(
        metricNames = metricNames,
        namespace = namespace ?: throw PulumiNullFieldException("namespace"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/cloudwatch/kotlin/inputs/MetricStreamIncludeFilterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.cloudwatch.kotlin.inputs

import com.pulumi.aws.cloudwatch.inputs.MetricStreamIncludeFilterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property metricNames An array that defines the metrics you want to include for this metric namespace
 * @property namespace Name of the metric namespace in the filter.
 */
public data class MetricStreamIncludeFilterArgs(
    public val metricNames: Output<List<String>>? = null,
    public val namespace: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.cloudwatch.inputs.MetricStreamIncludeFilterArgs> {
    override fun toJava(): com.pulumi.aws.cloudwatch.inputs.MetricStreamIncludeFilterArgs =
        com.pulumi.aws.cloudwatch.inputs.MetricStreamIncludeFilterArgs.builder()
            .metricNames(metricNames?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .namespace(namespace.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MetricStreamIncludeFilterArgs].
 */
@PulumiTagMarker
public class MetricStreamIncludeFilterArgsBuilder internal constructor() {
    private var metricNames: Output<List<String>>? = null

    private var namespace: Output<String>? = null

    /**
     * @param value An array that defines the metrics you want to include for this metric namespace
     */
    @JvmName("ofpyctgntimohdgl")
    public suspend fun metricNames(`value`: Output<List<String>>) {
        this.metricNames = value
    }

    @JvmName("snnetpfqwxhhbgam")
    public suspend fun metricNames(vararg values: Output<String>) {
        this.metricNames = Output.all(values.asList())
    }

    /**
     * @param values An array that defines the metrics you want to include for this metric namespace
     */
    @JvmName("innfngsqinlwnmuh")
    public suspend fun metricNames(values: List<Output<String>>) {
        this.metricNames = Output.all(values)
    }

    /**
     * @param value Name of the metric namespace in the filter.
     */
    @JvmName("ahuerdpeyqngwgmg")
    public suspend fun namespace(`value`: Output<String>) {
        this.namespace = value
    }

    /**
     * @param value An array that defines the metrics you want to include for this metric namespace
     */
    @JvmName("oohnjgbgpyuoqgje")
    public suspend fun metricNames(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.metricNames = mapped
    }

    /**
     * @param values An array that defines the metrics you want to include for this metric namespace
     */
    @JvmName("cflnwfapskrdsaov")
    public suspend fun metricNames(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.metricNames = mapped
    }

    /**
     * @param value Name of the metric namespace in the filter.
     */
    @JvmName("ckubwkmaxinjfgbv")
    public suspend fun namespace(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.namespace = mapped
    }

    internal fun build(): MetricStreamIncludeFilterArgs = MetricStreamIncludeFilterArgs(
        metricNames = metricNames,
        namespace = namespace ?: throw PulumiNullFieldException("namespace"),
    )
}
